@@ -62,7 +62,7 @@ def run(
     ),
     group: bool = typer.Option(
         False,
-        '--group',
+        '--grouped',
         help='Group process by description.',
     ),
     gt_mem: float = typer.Option(
@@ -86,7 +86,7 @@ def run(
     no_color: bool = typer.Option(
         False,
         '--no-color',
-        help='Omit row coloring.',
+        help='Disable output coloring.',
     ),
 ):
     if version:
